@@ -13,6 +13,9 @@ FIXED_TEMPERATURE = 0.0
 RANDOM_TEMPERATURE = 0.7
 MAX_INPUT_TOKENS = 3872
 MAX_OUTPUT_TOKENS = 256
-EMBEDDING_MODEL = lambda prompt: openai.Embedding.create(
-    input=[prompt], model="text-embedding-ada-002"
-)["data"][0]["embedding"]
\ No newline at end of file
+
+
+def EMBEDDING_MODEL(prompt):
+    return openai.Embedding.create(
+        input=[prompt], model="text-embedding-ada-002"
+    )["data"][0]["embedding"]
