@@ -1,5 +1,7 @@
 from llama.program.value import Value
 
+from llama.program.util.type_to_dict import value_to_dict, type_to_dict
+
 import json
 
 
@@ -11,7 +13,7 @@ class CallOperation(Value):
 
     def _to_dict(self):
         if isinstance(self._input_value, Value):
-            input_value = self._input_value.index
+            input_value = self._input_value._index
         else:
             input_value = {
                 "data": self._input_value.dict(),
@@ -22,11 +24,12 @@ class CallOperation(Value):
             "name": "CallOperation",
             "function_name": self._target_function.name,
             "input_value": input_value,
+            "type": type_to_dict(self._type)
         }
 
 
 def get_type(output_value):
-    if type(output_value) == tuple:
+    if isinstance(output_value, tuple):
         return (value.type for value in output_value)
 
     return output_value._type
