@@ -1,5 +1,7 @@
 from llama.program.value import Value
 
+from llama.program.util.type_to_dict import type_to_dict
+
 class GetArgumentOperation(Value):
     def __init__(self, type, input_value_index):
         super().__init__(type)
@@ -8,6 +10,8 @@ class GetArgumentOperation(Value):
     def _to_dict(self):
         return {
             "name" : "GetArgumentOperation",
-            "index" : self._input_value_index
+            "input_value" : {
+                "index" : self._input_value_index,
+                "type" : type_to_dict(self._type)
+            }
         }
-
