@@ -1,19 +1,24 @@
 import config
 import os
 
+global_config = None
+
 
 def get_config():
-    global_config = setup_config()
+    global global_config
+    assert global_config is not None
     return global_config
 
 
-def setup_config():
-    config_set = config.ConfigurationSet(
+def setup_config(dictionary={}):
+    global global_config
+    global_config = config.ConfigurationSet(
+        config.config_from_dict(dictionary),
         config.config_from_env(
             prefix="POWERML", separator="__", lowercase_keys=True),
         home_yaml_config(),
     )
-    return config_set
+    return global_config
 
 
 def home_yaml_config():
