@@ -5,14 +5,17 @@ import json
 
 
 def type_to_dict(type):
-    if type == BaseSpecification:
-        return json.loads(self._type.schema_json()),
+    if issubclass(type, BaseSpecification):
+        return json.loads(type.schema_json()),
 
-    return { "type" : str(type) }
+    return str(type)
 
 def value_to_dict(input_value):
     if isinstance(input_value, Value):
-        return input_value._index
+        return {
+            "index" : input_value._index,
+            "type" : type_to_dict(input_value._type),
+        }
 
     return {
         "data": rewrite_dict_data(input_value),
@@ -22,6 +25,7 @@ def value_to_dict(input_value):
 
 def rewrite_dict_data(input_value):
     if isinstance(input_value, Value):
+        assert False
         return input_value._index
     elif isinstance(input_value, BaseSpecification):
         input_value = input_value.dict()
